# antodo

another todo CLI app with some useful features

## Requirements

- Python 3.7

## Installation

```shell
pip install antodo
```

## Usage

add todo

```shell
antodo add do something
```

add urgent todo

```shell
antodo add -u do something
```

show current todos

```shell
antodo show
```

remove todo by index based on todos order

```shell
antodo remove 1 2
```

set todo as urgent by index based on todos order

```shell
antodo urgent 3
```

## Features

- [x] basic todo add/remove/list
- [x] set todo as urgent
- [ ] set timer for todo with deskop notification
- [ ] todo tags
